@@ -64,7 +64,7 @@ fn status_error() {
     "exit-2": "#!/usr/bin/env bash\nexit 2\n",
   };
 
-  cmd_unit!(%"chmod +x", tmp.path().join("exit-2"));
+  ("chmod", "+x", tmp.path().join("exit-2")).run();
 
   let path = env::join_paths(
     iter::once(tmp.path().to_owned()).chain(env::split_paths(&env::var_os("PATH").unwrap())),
@@ -79,9 +79,10 @@ fn status_error() {
     .output()
     .unwrap();
 
-  assert_eq!(
-    String::from_utf8_lossy(&output.stderr),
-    "error: Editor `exit-2` failed: exit code: 2\n"
+  assert!(
+    Regex::new("^error: Editor `exit-2` failed: exit (code|status): 2\n$")
+      .unwrap()
+      .is_match(str::from_utf8(&output.stderr).unwrap(),)
   );
 
   assert_eq!(output.status.code().unwrap(), 2);
